# Topsis-Udit-102203558
A Python package for implementing the TOPSIS (Technique for Order Preference by Similarity to Ideal Solution) method.

## Installation
```bash
pip install Topsis-Udit-102203558
```

## Usage
```python
from topsis import topsis

# Example usage
topsis('input_file.csv', 'weights', 'impacts', 'output_file.csv')
```

## Author
Udit Arora
